@@ -2,7 +2,6 @@ from django.db import migrations
 
 from aleksis.apps.ldap.util.ldap_sync import setting_name_from_field
 from aleksis.core.models import Person
-from django.contrib.sites.models import Site
 
 _preference_suffixes = ["", "_re", "_replace"]
 
@@ -15,22 +14,13 @@ def _setting_name_old(model, field):
 def _migrate_preferences(apps, schema_editor):
     SitePreferenceModel = apps.get_model("core", "SitePreferenceModel")
 
-    current_site = Site.objects.get_current()
-
     for field in Person.syncable_fields():
         old_setting_name = _setting_name_old(Person, field)
         setting_name = setting_name_from_field(Person, field)
         for suffix in _preference_suffixes:
             old_pref_name = old_setting_name + suffix
             new_pref_name = setting_name + suffix
-            qs = SitePreferenceModel.objects.filter(section="ldap", name=old_pref_name)
-            if qs.exists():
-                SitePreferenceModel.objects.update_or_create(
-                    instance=current_site.pk,
-                    section="ldap",
-                    name=new_pref_name,
-                    defaults={"raw_value": qs[0].raw_value},
-                )
+            SitePreferenceModel.objects.filter(section="ldap", name=old_pref_name).update(name=new_pref_name)
 
 
 class Migration(migrations.Migration):
